# py_me

**py_me** é uma biblioteca Python que oferece módulos para manipulação de sons (`music_me`) e interfaces gráficas com Tkinter (`tk_me`).

## versão

**1.2.2** - *lançado em 1/10/2025*

## mudanças

- correção de alguns bugs

## Instalação

```bash
pip install py-me